==> elgg-1.12.16.zip: elgg-1.12.16/mod/groups/languages/ru.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'groups' => "Группы",
	'groups:owned' => "Ваши собственные группы",
	'groups:owned:user' => 'Группы владельца %s ',
	'groups:yours' => "Группы, в которых состоите",
	'groups:user' => "Группы пользователя %s",
	'groups:all' => "Все группы на сайте",
	'groups:add' => "Создать группу",
	'groups:edit' => "Редактировать группу",
	'groups:delete' => 'Удалить группу',
	'groups:membershiprequests' => 'Управление запросами приглашения',
	'groups:membershiprequests:pending' => 'Управление запросами приглашений (%s)',
	'groups:invitations' => 'Приглашения группы',
	'groups:invitations:pending' => 'Приглашения группы (%s)',

	'groups:icon' => 'Иконка группы',
	'groups:name' => 'Название группы',
	'groups:username' => 'Краткое название группы',
	'groups:description' => 'Описание',
	'groups:briefdescription' => 'Краткое описание',
	'groups:interests' => 'Интересы',
	'groups:website' => 'Сайт',
	'groups:members' => 'Участники',
	'groups:my_status' => 'Мой статус',
	'groups:my_status:group_owner' => 'Вы владеете этой группой',
	'groups:my_status:group_member' => 'Вы в этой группе',
	'groups:subscribed' => 'Уведомления группы включены',
	'groups:unsubscribed' => 'Уведомления группы выключены',

	'groups:members:title' => 'Участники %s',
	'groups:members:more' => "Показать всех участников группы",
	'groups:membership' => "Ограничения в членстве",
	'groups:content_access_mode' => "Доступность контента группы",
	'groups:content_access_mode:warning' => "Внимание: Изменение этой настройки не поменяет права доступа на существующий контент группы.",
	'groups:content_access_mode:unrestricted' => "Не ограничено - Доступ зависит от настроек доступа записи",
	'groups:content_access_mode:membersonly' => "Только участникам - Не участники группы не смогут получить доступ к контенту группы",
	'groups:access' => "Доступ к группе",
	'groups:owner' => "Владелец",
	'groups:owner:warning' => "Внимание: если вы измените это значение, вы больше не будете владельцем группы.",
	'groups:widget:num_display' => 'Число отображаемых групп',
	'groups:widget:membership' => 'Членство',
	'groups:widgets:description' => 'Число отображаемых групп',

	'groups:widget:group_activity:title' => 'Активность группы',
	'groups:widget:group_activity:description' => 'Посмотреть активность в одной из ваших групп',
	'groups:widget:group_activity:edit:select' => 'Выберите группы',
	'groups:widget:group_activity:content:noactivity' => 'В этой группе нет активности',
	'groups:widget:group_activity:content:noselect' => 'Измените этот виджет и укажите группу',

	'groups:noaccess' => 'Нет доступа к группе',
	'groups:permissions:error' => 'Вы не можете редактировать эту группу',
	'groups:ingroup' => 'в группе',
	'groups:cantcreate' => 'Вы не можете создать группу. Только админы могут.',
	'groups:cantedit' => 'Вы не можете редактировать эту группу',
	'groups:saved' => 'Сохранено',
	'groups:save_error' => 'Group could not be saved',
	'groups:featured' => 'Избранные группы',
	'groups:makeunfeatured' => 'Убрать из избранного',
	'groups:makefeatured' => 'Добавить в избранные',
	'groups:featuredon' => 'Сделано.',
	'groups:unfeatured' => 'Убрано.',
	'groups:featured_error' => 'Ошибка.',
	'groups:nofeatured' => 'Нет избранных групп',
	'groups:joinrequest' => 'Попросить членство',
	'groups:join' => 'Вступить в группу',
	'groups:leave' => 'Покинуть группу',
	'groups:invite' => 'Пригласить в группу',
	'groups:invite:title' => 'Пригласить в группу',
	'groups:inviteto' => "Пригласить в '%s'",
	'groups:nofriends' => "Все друзья приглашены.",
	'groups:nofriendsatall' => 'Некого приглашать!',
	'groups:viagroups' => "в группе",
	'groups:group' => "Группа",
	'groups:search:tags' => "Интересы",
	'groups:search:title' => "Искать группу по интересам: '%s'",
	'groups:search:none' => "Ничего не найдено!",
	'groups:search_in_group' => "Поиск в этой группе",
	'groups:acl' => "Группа: %s",

	'discussion:topic:notify:summary' => 'Новое обсуждение %s',
	'discussion:topic:notify:subject' => 'Новое обсуждение: %s',
	'discussion:topic:notify:body' =>
'%s добавил[а] новое обсуждение в группу %s:

Тема: %s

%s

Посмотреть и ответить по ссылке:
%s
',

	'discussion:reply:notify:summary' => 'Новый ответ в обсуждении: %s',
	'discussion:reply:notify:subject' => 'Новый ответ в обсуждении: %s',
	'discussion:reply:notify:body' =>
'%s ответил[а] в теме %s в группе %s:

%s

Посмотреть и ответить по ссылке:
%s
',

	'groups:activity' => "Активность группы",
	'groups:enableactivity' => 'Включить активность группы',
	'groups:activity:none' => "---",

	'groups:notfound' => "Группа не найдена",
	'groups:notfound:details' => "Запрашиваемая группа или не существует, или у Вас нет доступа к ней",

	'groups:requests:none' => 'Пока нет никаких запросов членства.',

	'groups:invitations:none' => 'There are no oustanding invitations at this time.',

	'item:object:groupforumtopic' => "Темы обсуждений",
	'item:object:discussion_reply' => "Ответы в обсуждении",

	'groupforumtopic:new' => "Новая тема",

	'groups:count' => "групп создано",
	'groups:open' => "открытая группа",
	'groups:closed' => "закрытая группа",
	'groups:member' => "участников",
	'groups:searchtag' => "Поиск групп по интересам",

	'groups:more' => 'Еще группы',
	'groups:none' => '---',

	/**
	 * Access
	 */
	'groups:access:private' => 'Закрыто - только по приглашениям',
	'groups:access:public' => 'Открыто - заходи, проходи народ!',
	'groups:access:group' => 'Group members only',
	'groups:closedgroup' => "Это закрытая группа.",
	'groups:closedgroup:request' => 'В этой групп вход только по приглашениям. Чтобы получить доступ, нажмите "Попросить членство" в ссылках меню.',
	'groups:closedgroup:membersonly' => "Это закрытая группа и просмотр содержимого возможен только для участников.",
	'groups:opengroup:membersonly' => "Содержание этой группы доступно только участникам.",
	'groups:opengroup:membersonly:join' => 'Чтобы стать участником группы, нажмите "Вступить в группу"',
	'groups:visibility' => 'Кто может просматривать группу?',

	/**
	 * Group tools
	 */
	'groups:enableforum' => 'Включить форум группы',
	'groups:lastupdated' => 'Последнее обновление %s от пользователя %s',
	'groups:lastcomment' => 'Последний комментарий %s от пользователя %s',

	/**
	 * Group discussion
	 */
	'discussion' => 'Обсуждения',
	'discussion:add' => 'Создать тему',
	'discussion:latest' => 'Последние обсуждения',
	'discussion:group' => 'Обсуждения группы',
	'discussion:none' => '---',
	'discussion:reply:title' => 'Ответ от %s',

	'discussion:topic:created' => 'Создано.',
	'discussion:topic:updated' => 'Обновлено.',
	'discussion:topic:deleted' => 'Удалено.',

	'discussion:topic:notfound' => 'Не найдено',
	'discussion:error:notsaved' => 'Не удалось сохранить',
	'discussion:error:missing' => 'Название и сообщение обязательно для заполнения',
	'discussion:error:permissions' => 'Недостаточно прав',
	'discussion:error:notdeleted' => 'Не удалось удалить',

	'discussion:reply:edit' => 'Изменить ответ',
	'discussion:reply:deleted' => 'Удалено.',
	'discussion:reply:error:notfound' => 'Ответ не найден',
	'discussion:reply:error:notfound_fallback' => "К сожалению, мы не можем найти указанный ответ, но мы перенаправляем вас в начало темы обсуждения.",
	'discussion:reply:error:notdeleted' => 'Не удалось удалить',

	'discussion:search:title' => 'Ответить на тему: %s',
	
	'admin:groups' => 'Группы',

	'reply:this' => 'Ответить',

	'group:replies' => 'Ответы',
	'groups:forum:created' => 'Создал %s с %d комментариями',
	'groups:forum:created:single' => 'Создал %s с %d ответами',
	'groups:forum' => 'Форум группы',
	'groups:addtopic' => 'Создать тему',
	'groups:forumlatest' => 'Последнее на форуме',
	'groups:latestdiscussion' => 'Последние дискуссии',
	'groupspost:success' => 'Ваш комментарий успешно размещен.',
	'groupspost:failure' => 'Не удалось добавить ваш ответ',
	'groups:alldiscussion' => 'Последние дискуссии',
	'groups:edittopic' => 'Редактировать тему',
	'groups:topicmessage' => 'Сообщение',
	'groups:topicstatus' => 'Статус темы',
	'groups:reply' => 'Комментировать',
	'groups:topic' => 'Тема',
	'groups:posts' => 'Ответы',
	'groups:lastperson' => 'Последний',
	'groups:when' => 'Когда',
	'grouptopic:notcreated' => 'Темы не созданы.',
	'groups:topicclosed' => 'Закрыта для обсуждения',
	'grouptopic:created' => 'Ваша тема создана.',
	'groups:topicsticky' => 'Требует нового обсуждения',
	'groups:topicisclosed' => 'Обсуждение закрыто.',
	'groups:topiccloseddesc' => 'Тема закрыта.',
	'grouptopic:error' => 'Простите, тема не может быть создана. Попробуйте снова.',
	'groups:forumpost:edited' => "Сообщение успешно отредактировано.",
	'groups:forumpost:error' => "Простите, произошла ошибка при редактировании.",

	'groups:privategroup' => 'Это личная группа, для просмотра требуется членство.',
	'groups:notitle' => 'Группы должны иметь название.',
	'groups:cantjoin' => 'Простите, невозможно вступить в группу.',
	'groups:cantleave' => 'Простите, невозможно покинуть группу.',
	'groups:removeuser' => 'Удалить из группы',
	'groups:cantremove' => 'Извините, не могу удалить из группы',
	'groups:removed' => '%s удален(а) из группы',
	'groups:addedtogroup' => 'Пользователь добавлен в группу.',
	'groups:joinrequestnotmade' => 'Простите, запрос не может быть осуществлен.',
	'groups:joinrequestmade' => 'Запрос осуществлен.',
	'groups:joined' => 'Вы вступили в группу!',
	'groups:left' => 'Вы покинули группу',
	'groups:notowner' => 'Простите, но вы не вледелец этой группы.',
	'groups:notmember' => 'Извините, но вы не участник этой группы.',
	'groups:alreadymember' => 'Вы уже состоите в этой группе!',
	'groups:userinvited' => 'Пользователь приглашен.',
	'groups:usernotinvited' => 'Простите, пользователь не может быть приглашен.',
	'groups:useralreadyinvited' => 'Пользователь уже был приглашен',
	'groups:invite:subject' => "%s you have been invited to join %s!",
	'groups:updated' => "Последнее сообщение",
	'groups:started' => "Начато пользователем",
	'groups:joinrequest:remove:check' => 'Удалить запрос приглашения?',
	'groups:invite:remove:check' => 'Удалить приглашение?',
	'groups:invite:body' => "Привет %s,

Вас пригласили вступить в группу '%s', кликните для подтверждения:

%s",

	'groups:welcome:subject' => "Добро пожаловать в группу %s!",
	'groups:welcome:body' => "Привет %s!

Вы член группы '%s'! Кликните для начала деятельности.

%s",

	'groups:request:subject' => "%s попросил вступить в группу %s",
	'groups:request:body' => "Привет %s,

%s попросил вступить в группу '%s', кликните для просмотра профиля:

%s

или нажмите для подтверждения запроса:

%s",

	/**
	 * Forum river items
	 */

	'river:create:group:default' => '%s создал(а) группу %s',
	'river:join:group:default' => '%s вступил(а) в группу %s',
	'river:create:object:groupforumtopic' => '%s добавил(а) новое сообщение на форум %s',
	'river:reply:object:groupforumtopic' => '%s ответил(а) на сообщение %s',
	'river:reply:view' => 'просмотреть ответ',

	'groups:nowidgets' => 'У группы не определены элементы.',


	'groups:widgets:members:title' => 'Члены группы',
	'groups:widgets:members:description' => 'Список членов группы',
	'groups:widgets:members:label:displaynum' => 'Список членов группы',
	'groups:widgets:members:label:pleaseedit' => 'Пожалуйста, настройте этот виджет.',

	'groups:widgets:entities:title' => "Объекты в группе",
	'groups:widgets:entities:description' => "Список объектов группы",
	'groups:widgets:entities:label:displaynum' => 'Список объектов группы.',
	'groups:widgets:entities:label:pleaseedit' => 'Пожалуйста, настройте этот виджет.',

	'groups:forumtopic:edited' => 'Тема форума отредактирована.',

	'groups:allowhiddengroups' => 'Хотите вступить в подпольную группу?',
	'groups:whocancreate' => 'Кто может создавать новые группы?',

	/**
	 * Action messages
	 */
	'group:deleted' => 'Группа и все содержимое удалено',
	'group:notdeleted' => 'Удаление невозможно',

	'group:notfound' => 'Невозможно найти тему форума',
	'grouppost:deleted' => 'Сообщения группы удалены',
	'grouppost:notdeleted' => 'Удаление невозможно',
	'groupstopic:deleted' => 'Тема удалена',
	'groupstopic:notdeleted' => 'Удаление невозможно',
	'grouptopic:blank' => 'Тем нет',
	'grouptopic:notfound' => 'Невозможно найти тему форума',
	'grouppost:nopost' => 'Пусто',
	'groups:deletewarning' => "Вы уверены, что хотите удалить эту группу? Возврата не будет!",

	'groups:invitekilled' => 'Приглашение удалено.',
	'groups:joinrequestkilled' => 'Запрос приглашения отклонен.',
	'groups:error:addedtogroup' => "Не удалось добавить %s в группу",
	'groups:add:alreadymember' => "%s уже состоит в этой группе",

	/**
	 * ecml
	 */
	'groups:ecml:discussion' => 'Обсуждения группы',
	'groups:ecml:groupprofile' => 'Профили группы',
);

==> elgg-2.3.3.zip: elgg-2.3.3/mod/groups/languages/ru.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'groups' => "Группы",
	'groups:owned' => "Ваши собственные группы",
	'groups:owned:user' => 'Группы владельца %s ',
	'groups:yours' => "Группы, в которых состоите",
	'groups:user' => "Группы пользователя %s",
	'groups:all' => "Все группы на сайте",
	'groups:add' => "Создать группу",
	'groups:edit' => "Редактировать группу",
	'groups:delete' => 'Удалить группу',
	'groups:membershiprequests' => 'Управление запросами приглашения',
	'groups:membershiprequests:pending' => 'Управление запросами приглашений (%s)',
	'groups:invitations' => 'Приглашения группы',
	'groups:invitations:pending' => 'Приглашения группы (%s)',

	'groups:icon' => 'Иконка группы',
	'groups:name' => 'Название группы',
	'groups:username' => 'Краткое название группы',
	'groups:description' => 'Описание',
	'groups:briefdescription' => 'Краткое описание',
	'groups:interests' => 'Интересы',
	'groups:website' => 'Сайт',
	'groups:members' => 'Участники',
	'groups:my_status' => 'Мой статус',
	'groups:my_status:group_owner' => 'Вы владеете этой группой',
	'groups:my_status:group_member' => 'Вы в этой группе',
	'groups:subscribed' => 'Group notifications are on',
	'groups:unsubscribed' => 'Group notifications are off',

	'groups:members:title' => 'Участники %s',
	'groups:members:more' => "Показать всех участников группы",
	'groups:membership' => "Ограничения в членстве",
	'groups:content_access_mode' => "Доступность контента группы",
	'groups:content_access_mode:warning' => "Внимание: Изменение этой настройки не поменяет права доступа на существующий контент группы.",
	'groups:content_access_mode:unrestricted' => "Не ограничено - Доступ зависит от настроек доступа записи",
	'groups:content_access_mode:membersonly' => "Только участникам - Не участники группы не смогут получить доступ к контенту группы",
	'groups:access' => "Доступ к группе",
	'groups:owner' => "Владелец",
	'groups:owner:warning' => "Внимание: если вы измените это значение, вы больше не будете владельцем группы.",
	'groups:widget:num_display' => 'Число отображаемых групп',
	'groups:widget:membership' => 'Членство',
	'groups:widgets:description' => 'Число отображаемых групп',

	'groups:widget:group_activity:title' => 'Активность группы',
	'groups:widget:group_activity:description' => 'Посмотреть активность в одной из ваших групп',
	'groups:widget:group_activity:edit:select' => 'Выберите группы',
	'groups:widget:group_activity:content:noactivity' => 'В этой группе нет активности',
	'groups:widget:group_activity:content:noselect' => 'Измените этот виджет и укажите группу',

	'groups:noaccess' => 'Нет доступа к группе',
	'groups:ingroup' => 'в группе',
	'groups:cantcreate' => 'Вы не можете создать группу. Только админы могут.',
	'groups:cantedit' => 'Вы не можете редактировать эту группу',
	'groups:saved' => 'Сохранено',
	'groups:save_error' => 'Группа не может быть сохранена',
	'groups:featured' => 'Избранные группы',
	'groups:makeunfeatured' => 'Убрать из избранного',
	'groups:makefeatured' => 'Добавить в избранные',
	'groups:featuredon' => 'Сделано.',
	'groups:unfeatured' => 'Убрано.',
	'groups:featured_error' => 'Ошибка.',
	'groups:nofeatured' => 'Нет избранных групп',
	'groups:joinrequest' => 'Попросить членство',
	'groups:join' => 'Вступить в группу',
	'groups:leave' => 'Покинуть группу',
	'groups:invite' => 'Пригласить в группу',
	'groups:invite:title' => 'Пригласить в группу',
	'groups:inviteto' => "Пригласить в '%s'",
	'groups:nofriends' => "Все друзья приглашены.",
	'groups:nofriendsatall' => 'Некого приглашать!',
	'groups:viagroups' => "в группе",
	'groups:group' => "Группа",
	'groups:search:tags' => "Интересы",
	'groups:search:title' => "Искать группу по интересам: '%s'",
	'groups:search:none' => "Ничего не найдено!",
	'groups:search_in_group' => "Поиск в этой группе",
	'groups:acl' => "Группа: %s",

	'groups:activity' => "Активность группы",
	'groups:enableactivity' => 'Включить активность группы',
	'groups:activity:none' => "---",

	'groups:notfound' => "Группа не найдена",
	'groups:notfound:details' => "Запрашиваемая группа или не существует, или у Вас нет доступа к ней",

	'groups:requests:none' => 'Пока нет никаких запросов членства.',

	'groups:invitations:none' => 'There are no oustanding invitations at this time.',

	'groups:count' => "групп создано",
	'groups:open' => "открытая группа",
	'groups:closed' => "закрытая группа",
	'groups:member' => "участников",
	'groups:searchtag' => "Поиск групп по интересам",

	'groups:more' => 'Еще группы',
	'groups:none' => '---',

	/**
	 * Access
	 */
	'groups:access:private' => 'Закрыто - только по приглашениям',
	'groups:access:public' => 'Открыто - заходи, проходи народ!',
	'groups:access:group' => 'Group members only',
	'groups:closedgroup' => "Это закрытая группа.",
	'groups:closedgroup:request' => 'В этой групп вход только по приглашениям. Чтобы получить доступ, нажмите "Попросить членство" в ссылках меню.',
	'groups:closedgroup:membersonly' => "Это закрытая группа и просмотр содержимого возможен только для участников.",
	'groups:opengroup:membersonly' => "Содержание этой группы доступно только участникам.",
	'groups:opengroup:membersonly:join' => 'Чтобы стать участником группы, нажмите "Вступить в группу"',
	'groups:visibility' => 'Кто может просматривать группу?',

	/**
	 * Group tools
	 */
	'groups:lastupdated' => 'Последнее обновление %s от пользователя %s',
	'groups:lastcomment' => 'Последний комментарий %s от пользователя %s',

	'admin:groups' => 'Группы',

	'groups:privategroup' => 'Это личная группа, для просмотра требуется членство.',
	'groups:notitle' => 'Группы должны иметь название.',
	'groups:cantjoin' => 'Простите, невозможно вступить в группу.',
	'groups:cantleave' => 'Простите, невозможно покинуть группу.',
	'groups:removeuser' => 'Удалить из группы',
	'groups:cantremove' => 'Извините, не могу удалить из группы',
	'groups:removed' => '%s удален(а) из группы',
	'groups:addedtogroup' => 'Пользователь добавлен в группу.',
	'groups:joinrequestnotmade' => 'Простите, запрос не может быть осуществлен.',
	'groups:joinrequestmade' => 'Запрос осуществлен.',
	'groups:joined' => 'Вы вступили в группу!',
	'groups:left' => 'Вы покинули группу',
	'groups:notowner' => 'Простите, но вы не вледелец этой группы.',
	'groups:notmember' => 'Извините, но вы не участник этой группы.',
	'groups:alreadymember' => 'Вы уже состоите в этой группе!',
	'groups:userinvited' => 'Пользователь приглашен.',
	'groups:usernotinvited' => 'Простите, пользователь не может быть приглашен.',
	'groups:useralreadyinvited' => 'Пользователь уже был приглашен',
	'groups:invite:subject' => "%s you have been invited to join %s!",
	'groups:started' => "Начато пользователем",
	'groups:joinrequest:remove:check' => 'Удалить запрос приглашения?',
	'groups:invite:remove:check' => 'Удалить приглашение?',
	'groups:invite:body' => "Привет %s,

Вас пригласили вступить в группу '%s', кликните для подтверждения:

%s",

	'groups:welcome:subject' => "Добро пожаловать в группу %s!",
	'groups:welcome:body' => "Привет %s!

Вы член группы '%s'! Кликните для начала деятельности.

%s",

	'groups:request:subject' => "%s попросил вступить в группу %s",
	'groups:request:body' => "Привет %s,

%s попросил вступить в группу '%s', кликните для просмотра профиля:

%s

или нажмите для подтверждения запроса:

%s",

	/**
	 * Forum river items
	 */

	'river:create:group:default' => '%s создал(а) группу %s',
	'river:join:group:default' => '%s вступил(а) в группу %s',

	'groups:nowidgets' => 'У группы не определены элементы.',


	'groups:widgets:members:title' => 'Члены группы',
	'groups:widgets:members:description' => 'Список членов группы',
	'groups:widgets:members:label:displaynum' => 'Список членов группы',
	'groups:widgets:members:label:pleaseedit' => 'Пожалуйста, настройте этот виджет.',

	'groups:widgets:entities:title' => "Объекты в группе",
	'groups:widgets:entities:description' => "Список объектов группы",
	'groups:widgets:entities:label:displaynum' => 'Список объектов группы.',
	'groups:widgets:entities:label:pleaseedit' => 'Пожалуйста, настройте этот виджет.',

	'groups:allowhiddengroups' => 'Хотите вступить в подпольную группу?',
	'groups:whocancreate' => 'Кто может создавать новые группы?',

	/**
	 * Action messages
	 */
	'group:deleted' => 'Группа и все содержимое удалено',
	'group:notdeleted' => 'Удаление невозможно',

	'group:notfound' => 'Невозможно найти тему форума',
	'groups:deletewarning' => "Вы уверены, что хотите удалить эту группу? Возврата не будет!",

	'groups:invitekilled' => 'Приглашение удалено.',
	'groups:joinrequestkilled' => 'Запрос приглашения отклонен.',
	'groups:error:addedtogroup' => "Не удалось добавить %s в группу",
	'groups:add:alreadymember' => "%s уже состоит в этой группе",

	/**
	 * ecml
	 */
	'groups:ecml:groupprofile' => 'Профили группы',
);
